/*
   model/tags.cc
   This file is part of the Osirion project and is distributed under
   the terms of the GNU General Public License version 2
*/

#include "model/tags.h"

namespace model
{

/* ---- class Tag -------------------------------------------------- */

Tag::Tag() : tag_location()
{
}

Tag::Tag(const Tag& other) : tag_location(other.location())
{
}

Tag::Tag(const math::Vector3f& location) : tag_location(location)
{
}

Tag::~Tag()
{
}

/* ---- class Light ------------------------------------------------ */

Light::Light() :
	Tag(),
	light_color(1.0f, 1.0f, 1.0f)
{
	light_entity = false;
	light_engine = false;
	light_strobe = false;

	light_radius = 1.0f;
	light_frequency = 1.0f;
	light_offset = 0.0f;
	light_time = 0.5f;

	light_flare = 0;

	light_texture = 0;
}

Light::Light(const Light& other) : 
	Tag(other),
	light_color(other.color())
{
	light_entity = other.entity();
	light_engine = other.engine();
	light_strobe = other.strobe();

	light_radius = other.radius();
	light_frequency = other.frequency();
	light_offset = other.offset();
	light_time = other.time();

	light_flare = other.flare();

	light_texture = other.texture();
}

Light::~Light()
{
}

/* ---- class Flare ------------------------------------------------ */

Flare::Flare() : Light()
{
	flare_cull = CullBack;
}

Flare::Flare(const Flare& other) : Light(other)
{
	flare_cull = other.cull();
}

Flare::~Flare()
{}

/* ---- class Particles -------------------------------------------- */

Particles::Particles() : Tag()
{
	particles_entity = false;
	particles_engine = false;
	particles_radius = 0.0f;
	particles_cull = CullNone;
}

Particles::Particles(const math::Vector3f& location) :
		Tag(location)
{
}

Particles::~Particles()
{
}

/* ---- class Dock ------------------------------------------------- */

Dock::Dock() : Tag()
{
	dock_radius = 0.01f;
}

Dock::Dock(const Dock& other) : Tag(other)
{
	dock_radius = other.radius();
}

Dock::~Dock()
{
}

/* ---- class Sound ------------------------------------------------- */

Sound::Sound() : Tag()
{
}

Sound::Sound(const Sound& other) : Tag(other),
		sound_name(other.name())
{
}

Sound::~Sound()
{
}

/* ---- class SubModel---------------------------------------------- */

SubModel::SubModel() : Tag()
{
	submodel_scale = 1.0f;
}

SubModel::SubModel(const SubModel& other) : Tag(other),
		submodel_name(other.name()),
		submodel_axis(other.axis())
{
	submodel_scale = other.scale();
}

SubModel::~SubModel()
{
}

}
